@@ -5,7 +5,7 @@ library(magrittr)
 test_that("exact_rank_prob is correct",{
   P <- matrix(c(0,0,1,1,1,0,0,0,1,0,0,0,0,0,1,rep(0,10)),5,5,byrow=TRUE)
   res <- exact_rank_prob(P)
-  exp_rank <- c(4/3,19/9,26/9,4+2/9,4+4/9)
+  exp_rank <- c(V1=4/3,V2=19/9,V3=26/9,V4=4+2/9,V5=4+4/9)
   
   expect_equal(res$lin.ext,9)
   expect_equal(round(res$expected.rank,6),round(exp_rank,6))
